\name{raida}
\alias{raida}
\title{Identify differentially abundant features}
\description{Estimate differentially abundant features (taxonomic or functional units) across conditions. }
\usage{raida(c.data, n.lib, show.ref.features = FALSE, show.all.features = FALSE, mtcm="BH", zsc = 0)}
\arguments{
  \item{c.data}{a data frame containing counts for both conditions.}
  \item{n.lib}{a vector containing the numbers of samples for both conditions.}
  \item{show.ref.features}{logical, whether to show the features found as the common divisor.}
  \item{show.all.features}{logical, whether to show a feature with less than 20\% of nonzero counts in each of both conditions in a final result.}
  \item{mtcm}{a multiple testing correction method.}
  \item{zsc}{a cutoff to determine the value of the epsilon in the modified ZIL model. The default is the minimum of non-zero ratios.}
}
\details{
  RAIDA selects possible common divisors (a set of features) across different conditions and transforms counts into log ratios with each possible common divisor. The log ratios are tested with a modified t-statistic to identify differentially abundant features (DAFs). To find the most probable DAFs, RAIDA assumes that majority of features are not differentially abundant and select the possible common divisor that yields the smallest number of DAFs.
}
\value{
  \item{p }{vector containing p-values.}
  \item{p.adj }{vector containing adjusted p-values.}
  \item{eta1 }{vector containing estimated probabilities of the false zero state for condition 1.}
  \item{mean1 }{vector containing estimated means of log ratios for condition 1.}
  \item{sd1 }{vector containing estimated standard deviations of log ratios for condition 1.}
  \item{eta2 }{vector containing estimated probabilities of the false zero state for condition 2.}
  \item{mean2 }{vector containing estimated means of log ratios for condition 2.}
  \item{sd2 }{vector containing estimated standard deviations of log ratios for condition 2.}
  \item{mod.pool.var }{vector containing estimated posterior variances of log ratios.}
}
\examples{
# load test data
data(tdata);

# number of samples for each condition
n.samples = c(15,15);

result = raida(tdata, n.samples);
# show differentially abundant features at the FDR < 0.05.
result[result$p.adj<0.05,];
}
\keyword{models}
\keyword{htest}
